

# Cell
from dataclasses import field
from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, Undefined

# Cell
from dataclasses import field
from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, Undefined


# AUTOGENERATED! DO NOT EDIT! File to edit: S3.ipynb (unless otherwise specified).

__all__ = ['S3Event']

# Cell
from dataclasses import field
from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, Undefined

# Cell
@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class S3Event:
  '''
    parse event from apigateway
  '''
  body: str
  headers: dict = field(default_factory = dict)
  statusCode: int = 200
  def getBody(self):
    return json.loads(self.body)
  def getProducts(self):
    return Products.from_json(self.body)
  def getKey(self, key='product'):
    return body.get(key)
  key = lambda self: json.loads(self.body)['key']
  firstKey = lambda self: next(iter(json.loads(self.body).items()))
  @classmethod
  def getKeyObject(cls, event):
    s3Event = event['Records'][0]
    bucket = s3Event['s3']['bucket']['name']
    key = s3Event['s3']['object']['key']
    return bucket, key



# AUTOGENERATED! DO NOT EDIT! File to edit: dynamodb.ipynb (unless otherwise specified).

__all__ = []

# Cell
#export
from dataclasses import field
from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, Undefined


# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"S3Event": "S3.ipynb",
         "Response": "apigateway.ipynb",
         "Event": "apigateway.ipynb",
         "Product": "apigateway.ipynb",
         "Products": "apigateway.ipynb"}

modules = ["S3.py",
           "apigateway.py",
           "dynamodb.py"]

doc_url = "https://thanakijwanavit.github.io/awsSchema/"

git_url = "https://github.com/thanakijwanavit/awsSchema/tree/master/"

def custom_doc_links(name): return None
